@@ -109,7 +109,7 @@ def create_equipment_type_multilabel_binarizer():
     for row in rows:
         equipment_types.extend(str(row["predicted_equipment_types"]).split(", "))
 
-    equipment_types = [i.upper().encode("utf-8") for i in equipment_types]
+    equipment_types = [i.upper() for i in equipment_types]
     equipment_mlb.fit([equipment_types])
 
     # Send Data to GCS Bucket
