@@ -367,8 +367,10 @@ class _SaveDataframeToGCS(DoFn):
 
     def process(self, df):
 
-        bundle_num = df.iloc[0]["load_id"]
-        filename = "load_features_" + str(bundle_num) + ".pkl"
+        load_id_column = df[['load_id']].copy()
+        bundle_num = load_id_column.iloc[0]["load_id"]
+        # drop load_id column
+        df.drop('load_id', axis=1, inplace=True)
 
         # fix bool values
         df['ftl'] = (df['ftl'] == 'True').astype(int)
@@ -429,14 +431,15 @@ class _SaveDataframeToGCS(DoFn):
 
         # Add Identity Matrix to feature matrix as suggested in documentation
         sparse_loads.data = np.nan_to_num(sparse_loads.data, copy=False)
-        sparse_loads = sparse_loads.tocsr()
+        sparse_loads = csr_matrix(sparse_loads)
 
-        df = pd.DataFrame.sparse.from_spmatrix(sparse_loads)
-
-        df.to_pickle(filename)
+        data = {"index": load_id_column, "data": sparse_loads}
+        
+        filename = "load_features_" + str(bundle_num) + ".pkl"
+        pickle.dump(data, open(filename, "wb"))
         upload_blob("load_features", filename, filename)
 
-        return [df, ]
+        return [data, ]
 
 
 class SaveDataframeToGCS(PTransform):
